@@ -30,6 +30,8 @@
 #define STARWHITIS_STATE 2
 #define STARWHITIS_END_STATE 3
 
+#define WITH_FQDN6
+
 /* This function is designed to tell us if a given character is one
  * in a list that we give it
  *
@@ -721,7 +723,7 @@ js_string *process_dname(csv2_read *stream, int starwhitis) {
         /* Get 1st character; we use a sub function so we can use the
          * same code as process_something */
         o = process_1stchar(stream,csv2_is_starwhitis_ordot,"Z");
-        if(o == 0) {
+        if(o == 0 || o->string == 0) {
                 return 0;
         }
 
@@ -1048,6 +1050,11 @@ int csv2_numeric_rtype(js_string *text_rtype) {
         if(js_qissame("fqdn4",text_rtype) == 1) {
                 return 65765;
         }
+#ifdef WITH_FQDN6
+        if(js_qissame("fqdn6",text_rtype) == 1) {
+                return 65766;
+        }
+#endif
         /* Obscure RR types follow */
         /* Obscure RFC1035 RR types */
         if(js_qissame("hinfo",text_rtype) == 1) {
@@ -1109,6 +1116,10 @@ int csv2_numeric_rtype(js_string *text_rtype) {
         if(js_qissame("loc",text_rtype) == 1) {
                 return RR_LOC;
         }
+        /* Maybe not obscure RFC3403 RR */
+        if(js_qissame("naptr",text_rtype) == 1) {
+                return RR_NAPTR;
+        }
         return -1;
 }
 
@@ -1721,6 +1732,13 @@ int csv2_read_rr(csv2_add_state *state, csv2_read *stream, int32 starwhitis) {
                              * PTR record */
                         rddata = csv2_get_a(stream);
                         break;
+#ifdef WITH_FQDN6
+                case 65766: /* FQDN6: This is an AAAA record where we
+                                  * automagically also make the corresponding
+                                  * PTR record */
+                        rddata = csv2_get_aaaa(stream);
+                        break;
+#endif
                 /* Obscure RRs follow */
                 case RR_HINFO:
                         rddata = csv2_get_txt(stream,2);
@@ -1766,6 +1784,9 @@ int csv2_read_rr(csv2_add_state *state, csv2_read *stream, int32 starwhitis) {
                         }
                         rddata = csv2_get_loc(stream);
                         break;
+                case RR_NAPTR:
+                        rddata = csv2_get_naptr(stream);
+                        break;
                 default:
                         /* RAW rtype */
                         if(rtype >= 100000 && rtype <= 165535) {
