@@ -635,3 +635,82 @@ js_string *csv2_get_loc(csv2_read *stream) {
 
 }
 
+/* This processes the somewhat complicated NAPTR RR (RFC3403, etc.) */
+
+js_string *csv2_get_naptr(csv2_read *stream) {
+        /* New coding style practices.  All variables, when feasible,
+         * are initialized when declared */
+        js_string *out = 0;
+        js_string *name = 0;
+        js_string *zone = 0;
+        int num = 0;
+        int c = 0;
+
+        out = js_create(256,1);
+        if(out == 0) {
+                return 0;
+        }
+
+        /* RFC3403 section 4.1 */
+        /* Get the "order" and "preference" (both numbers) */
+        for(c = 1; c <= 2; c++) {
+                if((num = csv2_get_num(stream)) < 0) {
+                        js_destroy(out);
+                        return 0;
+                }
+                if(js_adduint16(out,num) == JS_ERROR) {
+                        js_destroy(out);
+                        return 0;
+                }
+        }
+
+        /* Get "flags", "services", and "regexp" (three TXT-type fields) */
+        name = csv2_get_string(stream,3);
+        if(name == 0) {
+                js_destroy(out);
+                return 0;
+        }
+
+        /* Append those three fields to the outputted name */
+        if(js_append(name,out) == JS_ERROR) {
+                js_destroy(name);
+                js_destroy(out);
+                return 0;
+        }
+
+        js_destroy(name);
+
+        /* Get "replacement" (Domain name) */
+        if(csv2_get_1st(stream,csv2_is_dchar,0) != JS_SUCCESS) {
+                js_destroy(out);
+                return 0;
+        }
+
+        zone = js_create(256,1); /* csv2_get_hostname expects zone to
+                                  * be valid js_string, so we just allocate
+                                  * an empty string */
+        if(zone == 0) {
+                js_destroy(out);
+                return 0;
+        }
+
+        name = csv2_get_hostname(stream,zone,3);
+
+        js_destroy(zone);
+
+        if(name == 0) {
+                js_destroy(out);
+                return 0;
+        }
+
+        /* Append the "replacment" to the outputted string */
+        if(js_append(name,out) == JS_ERROR) {
+                js_destroy(name);
+                js_destroy(out);
+                return 0;
+        }
+
+        js_destroy(name);
+        return out;
+}
+
